pub enum SignerError {
MissingCredentials {
reason: String,
},
InvalidCredentials {
reason: String,
},
SigningFailed {
reason: String,
},
StorageUnavailable {
reason: String,
},
ExpiredToken {
reason: String,
},
WrongStrategy {
strategy: CredentialStrategy,
},
}Expand description
Signing failures returned by crate::Signer and crate::SignerFactory.
Variants
MissingCredentials
No credentials are configured for the selected upstream.
InvalidCredentials
Credentials exist but cannot be used.
SigningFailed
Signing failed.
Credential storage is temporarily unavailable.
ExpiredToken
OAuth access token is expired or within the signer refresh skew window.
WrongStrategy
The factory was asked to build a signer for the wrong strategy.
Fields

strategy: CredentialStrategySelected auth strategy.