pub enum SubscriptionQuotaDataState {
Fresh,
Stale,
Missing,
}Expand description
Freshness state for subscription quota data exposed to router plugins.
Variants
Fresh
Data is inside the configured routing freshness window.
Stale
Data exists but is older than the configured routing freshness window.
Missing
No usable subscription quota data exists for the candidate/window.