SignedRequest

Struct SignedRequest 

pub struct SignedRequest { /* private fields */ }
Request after a signer has consumed and sealed a shaped request.

Implementations

Source

impl SignedRequest

pub fn from_shaped( shaped: ShapedRequest, _capability: &mut SigningCapability, ) -> Self

Seals an owned shaped request after the signer has applied credentials.

pub fn url(&self) -> &Url

Returns the destination URL.

pub fn method(&self) -> &Method

Returns the HTTP method.

pub fn headers(&self) -> &HeaderMap

Returns the signed request headers.

pub fn body(&self) -> &Bytes

Returns the signed request body.

pub fn into_parts(self) -> (Url, Method, HeaderMap, Bytes)

Consumes the signed request into relay-ready parts.