UpstreamCandidate

Struct UpstreamCandidate 

pub struct UpstreamCandidate {
    pub upstream_id: Uuid,
    pub name: String,
    pub kind: UpstreamKind,
    pub observed_rate_limits: Vec<RateLimitObservation>,
    pub subscription_quotas: Vec<SubscriptionQuotaCandidateSnapshot>,
    pub observed_at_unix_secs: u64,
    pub cache_score: Option<CacheScore>,
    pub base_url: Option<String>,
}
Available upstream candidate for routing decisions.

The router receives a list of available upstream candidates sorted by upstream_id in ascending order (Uuid byte order). This stable ordering allows plugins to implement deterministic routing algorithms.

Fields

upstream_id: Uuid

Stable upstream identifier.

name: String

Operator-facing upstream name.

kind: UpstreamKind

Upstream kind used to select compatible routing strategies.

observed_rate_limits: Vec<RateLimitObservation>

Latest rate-limit observations for this candidate.

subscription_quotas: Vec<SubscriptionQuotaCandidateSnapshot>

Latest subscription quota snapshots for this candidate.

observed_at_unix_secs: u64

Unix timestamp in seconds for the candidate observation snapshot.

cache_score: Option<CacheScore>

Predicted cache utility for this candidate, if available.

base_url: Option<String>

Resolved upstream base URL. Populated by the host so that v2 plugins that self-reference for shape can construct the dispatch URL against the configured upstream instead of hardcoding api.anthropic.com.