pub struct RouteDecision {
pub upstream_id: Option<Uuid>,
pub upstream: Upstream,
pub dialect: Arc<dyn UpstreamDialect>,
}Expand description
Router output selecting both an upstream and its dialect boundary object.
Fields
upstream_id: Option<Uuid>Stable upstream identifier selected by the router, when provided by the plugin.
upstream: UpstreamUpstream selected for the request.
dialect: Arc<dyn UpstreamDialect>Dialect plugin that shapes the request for the selected upstream.