pub struct SignedRequest { /* private fields */ }Expand description
Request after a signer has consumed and sealed a shaped request.
Implementations
Sourceimpl SignedRequest
impl SignedRequest
Sourcepub fn from_shaped(
shaped: ShapedRequest,
_capability: &mut SigningCapability,
) -> Self
pub fn from_shaped( shaped: ShapedRequest, _capability: &mut SigningCapability, ) -> Self
Seals an owned shaped request after the signer has applied credentials.